"use strict";var s=function(e,o){return function(){return o||e((o={exports:{}}).exports,o),o.exports}};var r=s(function(p,t){
function u(){return typeof Symbol=="function"&&typeof Symbol("foo")=="symbol"}t.exports=u
});var i=r();module.exports=i;
/** @license Apache-2.0 */
//# sourceMappingURL=index.js.map
